//+------------------------------------------------------------------+
//|                                               Moving Average.mq4 |
//|                      Copyright  2005, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//+------------------------------------------------------------------+
#define MAGICMA  20050610

extern double Lots               = 0.1;
extern double StopLoss           = 30;
extern double MaximumRisk        = 0.005;
extern double DecreaseFactor     = 3;
extern double MovingPeriod       = 20;
extern double MovingShift        = 6;
extern bool   UseTrailing        = true;
extern int    TrailingStop       = 20;
extern bool   UseAutoClose       = false;
//+------------------------------------------------------------------+
//| Calculate open positions                                         |
//+------------------------------------------------------------------+
int CalculateCurrentOrders(string symbol)
  {
   int buys=0,sells=0;
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false) break;
      if(OrderSymbol()==Symbol() && OrderMagicNumber()==MAGICMA)
        {
         if(OrderType()==OP_BUY)  buys++;
         if(OrderType()==OP_SELL) sells++;
        }
     }
//---- return orders volume
   if(buys>0) return(buys);
   else       return(-sells);
  }
//+------------------------------------------------------------------+
//| Calculate optimal lot size                                       |
//+------------------------------------------------------------------+
double LotsOptimized()
  {
   double lot=Lots;
   
//---- select lot size
   lot=0.1;

//---- return lot size
   if(lot<0.1) lot=0.1;
   return(lot);
  }
//+-----------------------------------------------------------------------------------------------------+
//DIGITS PART//
  int BrokerPoint()
  {
  int MYpoint=1;
  if(Digits==5||Digits==3) MYpoint=10;
  return(MYpoint);
  }
//+------------------------------------------------------------------+
//| Check for open order conditions                                  |
//+------------------------------------------------------------------+
void CheckForOpen()
  {
   double ma;
   int    res;
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
//---- get Moving Average 
   ma=iMA(NULL,0,MovingPeriod,MovingShift,MODE_SMA,PRICE_CLOSE,0);
//---- sell conditions
   if(Open[1]>ma && Close[1]<ma)  
     {
      res=OrderSend(Symbol(),OP_SELL,LotsOptimized(),Bid,3,Bid+(StopLoss*(Point*BrokerPoint())),0,"",MAGICMA,0,Red);
      return;
     }
//---- buy conditions
   if(Open[1]<ma && Close[1]>ma)  
     {
      res=OrderSend(Symbol(),OP_BUY,LotsOptimized(),Ask,3,Ask-(StopLoss*(Point*BrokerPoint())),0,"",MAGICMA,0,Blue);
      return;
     }
//----
  }
//+------------------------------------------------------------------+
//| Trailing Stop function                                           |
//+------------------------------------------------------------------+
void Trailing_Stop()
   {
   for(int cnt = OrdersTotal() - 1; cnt >= 0; cnt--)
      {
      OrderSelect(cnt, SELECT_BY_POS, MODE_TRADES);
      //----
      if(OrderSymbol() == Symbol() && OrderMagicNumber() == MAGICMA)
         {       
	  	   if(OrderType() == OP_BUY)
	  	      {
	  		   if(TrailingStop > 0) 
	  		      {
			      if(Bid - OrderOpenPrice() >= TrailingStop *(Point*BrokerPoint()))
			         {
	               if(OrderStopLoss() < (Bid - ((Point*BrokerPoint())*TrailingStop))) 
                     {					   
				         OrderModify(OrderTicket(), OrderOpenPrice(), Bid - ((Point*BrokerPoint())*TrailingStop), 0, 0, Yellow);
				         return(0);
	  		            }
	  		         }
	  		      }
	  		   }
	  	   if(OrderType() == OP_SELL) 
	  	      {
	  	      if(TrailingStop > 0) 
	  	         {
		         if(OrderOpenPrice() - Ask >= TrailingStop *(Point*BrokerPoint()))
		            {
		            if(OrderStopLoss() > (Ask + ((Point*BrokerPoint())*TrailingStop)))
		               {
		               OrderModify(OrderTicket(), OrderOpenPrice(), Ask + ((Point*BrokerPoint())*TrailingStop), 0, 0, Purple);
		               return(0);
		               }
   	            }
               } 
            }
         }
      }
   }

//+------------------------------------------------------------------+
//| Check for close order conditions                                 |
//+------------------------------------------------------------------+
void CheckForClose()
  {
   double ma;
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
//---- get Moving Average 
   ma=iMA(NULL,0,MovingPeriod,MovingShift,MODE_SMA,PRICE_CLOSE,0);
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false)        break;
      if(OrderMagicNumber()!=MAGICMA || OrderSymbol()!=Symbol()) continue;
      //---- check order type 
      if(OrderType()==OP_BUY)
        {
         if(Open[1]>ma && Close[1]<ma) OrderClose(OrderTicket(),OrderLots(),Bid,3,White);
         break;
        }
      if(OrderType()==OP_SELL)
        {
         if(Open[1]<ma && Close[1]>ma) OrderClose(OrderTicket(),OrderLots(),Ask,3,White);
         break;
        }
     }
//----
  }

//+------------------------------------------------------------------+
//| Start function                                                   |
//+------------------------------------------------------------------+
void start()
  {
//---- check for history and trading
   if(Bars<100 || IsTradeAllowed()==false) return;
//---- calculate open orders by current symbol
   if(CalculateCurrentOrders(Symbol())==0) CheckForOpen();
   else 
   if((UseTrailing==true)&&(UseAutoClose==false))  Trailing_Stop();
   if((UseTrailing==true)&&(UseAutoClose==true))   Trailing_Stop(); CheckForClose();
   if((UseTrailing==false)&&(UseAutoClose==true))  CheckForClose();
//----
  }
//+------------------------------------------------------------------+---+

